@@ -10,7 +10,7 @@ use URI ();
 use Try::Tiny qw(try catch);
 
 our @EXPORT  = qw(makeashorterlink makealongerlink);
-our $VERSION = '2.100';
+our $VERSION = '2.101';
 $VERSION = eval $VERSION;
 
 sub makeashorterlink {
@@ -117,9 +117,13 @@ Iain Truskett <spoon@cpan.org>
 
 =over
 
-=item Chase Whitener C<capoeirab@cpan.org> -- current maintainer
+=item *
 
-=item Dave Cross C<dave@perlhacks.com>
+Chase Whitener C<capoeirab@cpan.org> -- current maintainer
+
+=item *
+
+Dave Cross C<dave@perlhacks.com>
 
 =back
 
